# pymeasurement
A Measurement Calculator with Fixed Point Precision, Uncertainties, and Units.

View at [PyPi], [Github], and [Read the Docs].

## Installation
pymeasurement is distributed on [PyPI]. 

```
pip install pymeasurement
```

## Usage and Documentation
Access the [Read the Docs] to learn about usage and documentation for this package.

[pypi]: https://pypi.org/project/pymeasurement/
[github]: https://github.com/Saptak625/pymeasurement
[Read the Docs]: https://pymeasurement.readthedocs.io/en/latest/
